@@ -2,7 +2,7 @@ import os
 
 class SampleInputTXT():
     def generate_sample(self) -> bool:
-        current_path = os.getcwd() + '/sample/example_bayesnet.txt'
+        current_path = os.getcwd() + '/bayes/example_bayesnet.txt'
         with open(current_path, 'r') as f:
             print(f.read())
         print("-"*25)
